
# q-expansion of newform 16.18.a.e, downloaded from the LMFDB on 05 November 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 16
weight = 18
poly_data = [-2340, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-192, 384], 1]]

hecke_ring_character_values = None
aps_data = [[0, 0], [2940, -1], [302022, -36], [-12675080, -594], [-629824140, -38115], [-660026290, -162756], [-13749113070, -175032], [-50566816916, 2861595], [-67383745560, 14187978], [1168577791326, -136229940], [-139418056736, 128935800], [10464901444070, -494092116], [2083296157866, 1902597840], [55571574267220, -1581547275], [-98386325578800, -5178600108], [-243982561368330, -12154446612], [-1417952098906812, -9148192335], [-33772017497218, -114760782180], [497585660773180, -109849087089], [-1941122746607688, 347319240030], [-6373212940884790, 6950534184], [7492135767032752, -360485585460], [-21949708904946900, -232562921877], [25954503979423194, 224724957480], [-24640503894924190, 3147743142504], [103793379193282086, -2625119677620], [-38753395895033960, 3699440983062], [-155212550420314860, -1521512512443], [-213076908720865618, -2815939263060], [-291147714764300430, 10003493400768], [351860939992608640, 23705120378016], [839137225964180220, -6570108903105], [-877873359218325750, -57629905233264], [-1463874306258785036, 12551416092765], [-1509666564827362986, 207041770601820], [-517886702965521560, -2139512226390], [-3018070771645103650, -114736277917764], [-359834277777876260, -543079363895145], [-305247571405013160, -579552191881146], [6847608282391127790, -443071065059172], [-9809623888812805428, -280532731890285], [3968189306621631350, -233035723262340], [-12625614513406058688, 196301056185360], [-18224147410438178110, -568157406544728], [51189660687408357510, 96325204861116], [-9889841272648685768, -829147997857410], [-15713525628292885844, -2854169434050165], [-36224055106125121760, 2187163514884680], [22468017907437587100, -2974689062958393], [66427368418068372134, 1562317968990780], [-138590641793041674390, -3716697939420312], [74650227039824722704, 10861877764597860], [138513564145323662834, 5215696093392840], [198915011863518932100, 10372162748004225], [270346405401715740930, 7777670582043648], [234921452618790119160, -17934666004760274], [189723719418467047758, 17936605773086220], [-410946897156202872080, -1948430719396260], [-499963762121497543210, 19578150386711532], [378571414734939802266, -13575362660770680], [355191540180868592740, -13836085348812903], [1232962539937392525030, -11679334370001540], [-514143613694258013620, -28789872030163629], [1748193893846321003208, -509528497849470], [-903851185162889698630, -89369046294066864], [837815615094711066750, -61599972315584052], [-496104326627828566988, -224581337439835635], [-1080765489293875415470, -30368749301374176], [3619246124476223253540, -145315401069370455], [-1093706727469438729570, -7826697400791060], [545831935340019150690, -151090617617511264], [7234840176734036237976, 147127602803580630], [-5590974725609238746480, 22587135302451204], [2931676111567697478710, 414641290593696012], [1035502461055597231108, 310907052405115425], [2722352459240185994880, 211680650938769568], [5640247385172725383494, 565443506807667180], [-11181715420738711324210, 656977515396906924], [852820939259653249170, -760928372096369400], [9568694740589232933146, 876665272655644560], [-12606652307272305507876, 65273414316830775], [-25116273240594997125274, -241609465188921060], [-20831690170702013912496, 121525115075913780], [7643981331574565919410, -319343867090192376], [6865714652983333542472, -2008681531807516830], [1461103748636560880580, 1122760592359879473], [-12948765713628476511294, -2412966332800560600], [-9948807054538195190710, -1875432482519138928], [9892196796303118829070, 3473950163202155340], [30278520895769724478000, 238364291787416172], [44063300109116002036140, -715835693647584405], [32627468449105911035424, -405983996711445240], [-51526530258262481375720, -3982527958533327882], [2020001837099846519700, -2959952349767334075], [5954835422401361625484, -1835901105769314045], [18886611262619528837640, 1901838814439395986], [-147890494243783022517954, -1632885141060248580], [41032331999749730513034, -3254588794472871600], [18511445588824236733300, 7927078503323745117], [12442266428169992569694, 916499067586710300], [46856520272513425457500, -6831446750454490857], [-96032616685090274477970, -3479488234681660740], [-84283484580036367787700, 9409116843905633811], [90064231160681298457530, 17941298601949707600], [91466473861728171955012, -4996323176769176175], [91534083575708022070850, -7479826472160415584], [-364722123066743084399820, 13919740572662351757], [12297084544616996020050, -16823820916845480384], [-50122901099651516268120, -5670220962058184070], [21946556013430947739610, -5008877004299941080], [-60528124695352994445920, 14442528633763449384], [697856296623183685082150, -8118074274887511396], [-282611680237904562745110, -15990406700910603192], [724448814439700461187860, -7610880946112959995], [-934383331930552781891192, -913903876412334990], [-1012482510601290433927038, 1902643676424507240], [-327423667515416408932100, -12328259322628040193], [165425923710406493963640, -71341444769400938034], [-79703213928834122210610, -48864551382401913396], [1124426283491686275432684, -33751199570549176485], [47448476834972569166678, -65016960871980667140], [-350593396253362942346590, -42051170928825622872], [758828258347858392542310, 18052564594079680236], [-59642788270052551234860, 2643281880212214549], [1415114739373434098495692, 10833101211979644435], [1173532619572259347891710, -53115214951193485860], [-1643047971531905320032634, 76671059952381391980], [1140154021150418726175024, 824882655197120940], [3475838179464793259270440, 5180492914116498522], [493004590639364575155230, -52937817097158575604], [-2162218526171041737537380, -618940430909708985], [-1028783985607153533997800, -110938739245106818122], [-2539235382644307142371056, -109950140379177026460], [1976992320838790581594550, -87954446749450984164], [1163600983954821785313402, 99540652545818629200], [-3299860323905345840520958, 168893657752594939560], [3521027768264564378310, -239188555008528481620], [-4951716034554846575955860, 107461610648873852283], [-2731849369053617775575970, -176492542482981784836], [1443395580764103901967274, 308112937613860856400], [-6372533275786696238140844, 34522417892358694485], [2211133427384197799604726, 13209937036096420620], [2810140712025036192266440, 390467410723100995074], [2930162082450235312456260, -282260388044567307375], [5293213679273490172192382, 10660393877608200060], [4282731661462774409422008, -359206393757588909730], [-9403943928954455799852010, 126899706105284660460], [-4132779958477101613173030, -138948376375297337904], [1471205824454775606757924, -541386560743131906135], [-890057194783469373229920, 345340741069539546408], [1145440663097660191099310, -414163554359376532788], [5395404606884961659263602, 20963519697809463840], [4087581514465440166217740, 727392625924770783747], [-13285972552150862132156280, 141254934024053758194], [15126220751885429162056180, 64424850591668440797], [-4802560744686444337414032, -527256470253478456260], [729692095574403116982376, -138313503138839566230], [3815077789141660292426658, -591027714171297425880], [-12805731010229652103823830, -215445235933887709464], [4521624336542044968261102, 1366906574946911369580], [-5809707927947286828075060, -230551083634142395341], [-9745765306226195253207750, 1060762077087953941008], [-15935012029823484209560520, 1106539924033865861694], [-19415661500197152491578956, 1126272450815540048205], [-18465289724943256558932270, -170319337181323404984], [3146999926382801011834920, -759093745990199200614], [-10601111220049223154531296, 1703169859988582120520], [-21469586937239847792340570, -3650879878155046548], [26697874632168614103871730, 680223955130564894280], [-24313472914692556370058570, 29219619139327759356], [-35034818043558234701614716, 1260454725685976189985], [19331884882240658663139134, 1997321349719782193580], [28444668496261345285047288, -1410713430398325130770], [41625849425032580681526410, -413771634862060189176], [44638643351666393012559856, 2081877994606242194460], [18928446713440218411769242, 2094909953912689365000], [6543941155457572194523492, -440780020302359759175], [-37383489607146000957637146, -1044938411853434188020], [-17813727040054024928035880, -4532926824983994817050], [-1452212028973064714251666, -4207987944191961846180], [-37838747189562529068061760, -1362593572418149028496], [-32923320655452071095580868, -2037364449040998823185], [-78124056015883809614396410, 370698077191195271196], [66367102851885393483911370, 706454992735487610120], [-56488847636248621046272080, 593985631822893324], [96824678840923791841564950, 601542642974458697820], [-23419843717277576707968610, -2452622711829085583172], [-9620418959473659173292260, 514171452826792428327], [-15028601705573565314025238, -4540609767267721390320], [47897249295055882423540608, -7114477980218492616480], [-164746128465253061908781950, -279793906126444852704], [64383892241595801241757940, -7101926180807788021923], [108283312956083236234233580, 3854616320830220870715], [30211320554265773233037790, 3299615166666529713420], [-25173402545985063560481060, 3371296183561602989847], [-89171598209010320539560150, 5354922884490047494728], [-65799442079523233511405646, -416592119219733293760], [172541200105038624526446590, -4469628833880806312388], [-162371893348180171529867070, 7550555784036683679360], [299332192176261290129945400, 1479672847845074441790], [35824303724800720845782286, -13982747177478728782980], [-170725369593433827281895632, 9220459038736288600620], [-6319851298384602487663210, -10705390202853959215284], [207286629670490596626723554, 7501446477798817420800], [57973160806540581845737620, 3382123961098098148005], [-102608396881655893238638530, -3191366622999986141652], [-26211312527902108575057152, 2773201570222508856000], [-289629621746062814753442180, -10903059942189021327105], [61622467199418727095219594, -7681889511516560460120], [256878229018787741637828724, -11968290568930935197475], [-39572792918004005695249390, 14167429742684403734472], [137150757838967021418683862, 17780714603430998972220], [-116735108793010082456228120, -14927982175857596183478], [-230345347343758985901997980, 17128064208037823481177], [317264449938533161325148888, -5601939230874355683930], [429245488720184468257240490, -773257249475093674800], [-17187555926103358902040880, 26765642778488072100180], [-381653416896189921209903022, -22202367888016886617080], [373269452947425296701865640, -15056980456987814514246], [-121709844946434502275219810, -22231677065076654473844], [300418585678670244444288806, 7429245604092058255740], [-232504151257167076526197112, -27597823156067391668430], [-194266182891461360509633662, 28662538318690921200360], [-52254467680139110110515600, 29836673591989026180348], [129739196851526887872550380, -634031870133461518917], [-187662677507629746346679722, 11865076777507286260620], [-266829802093452272313487590, 46342775487193714279080], [312949090152254654889890400, 5780914353620752915800], [-719904482293384919825192360, 5582910517988096025414], [-54753221046833961403451436, 49674514386828505138965], [731549307232455246975746030, -4254969567647696499252], [448984930669141050837353932, -26262671626326338598285], [-538009232842117316012815808, -31890611066784098373360], [369900910117428364876802634, -62334847977802465637880], [409890881873240720340064180, 10336253280089106734541], [467797952421672071765171760, -8944100501804068382100], [-529954349298089036886089518, -22656030928886137142520], [-479514258659419483399411050, -42796615368057843857796], [-1666261523452986868469567580, 10193863065920902058985], [-461846921567093928342910440, -27946806622288095489930], [-1401051870339669017407742580, 4498833064401120142467], [-1363935192386022652368904316, 16770856686321388930785], [990598831329132899461267960, 24450549960194252857710], [-244167644396153466153092530, 85093525630066906074780], [8250445469635463565764370, -57139072747794375734880], [-175213784845799402488803864, -7866860047039966568310], [-1274810952710796410255605280, -41944636829394112045320], [-493364406229807635927683748, -100015968774803014378665], [326371540409987630143563604, 36546401188179020300085], [559574592916265282280949200, 32044581330162020975124], [-281230976811924494141452930, 7272172959368209241580], [1076154151502651294230282818, -28705819570920300837600], [1678968172723463088152228280, 40433111435976342050142], [-1088095200408904267658229046, 79930133716527352094760], [2548869501632467095180466830, -30991119500404300852692], [-588677463361904836284797652, 27589561582698068915115], [1173440978319891610459851542, -110802341779611826210020], [799714507996004202916075300, 124476794276859924071337], [305876619219226494038428710, 112927190813263697092524], [68338950836852771322407930, -112738694652427939611120], [12864461959050727749032320, 102893917955996366980704], [3358014257988909929512240380, -40760920929700261335969], [361388590491759638228237894, 74892633197580722678220], [1656416519545162520828672990, 155332681959352268838060], [-822412717994671478147952990, 126129940721596379879784], [1691469683148887758023515356, -165474163435473287116425], [894804075423507084379732206, 124480623094090871268780], [2459119423830674084731871802, -26792628586534625655960], [-98129162662432584593865020, 182082282289238890664721], [368709796408727139965641350, -21974800624863525977076], [-1222959922224816478369427698, 29876705464946883392700], [-4384598226425238201786473300, 440902118592521850411], [-2075399672450608162455024550, 92134373031089655370632], [-2463382962951298050347589344, 259735164606167993293320], [-933815759126511401042233870, -133333861775573128896864], [-3422850197469575475894938360, 55689648394439343860946], [2024248375603273309020692100, 263268132930947489379489], [-5544182264461501960749476290, -77696185514223145064580], [-3330914051555542029927819382, 164977436805597071104680], [1476193677753332396855301228, -71324686654823614974885], [1024532744153949154171887840, 394838437872992323856184], [2936664889231997038002301144, -182186239744781792124570], [4438903605458458786846950600, -234695271916804800351294], [-1209381638124114464544626938, -417987978055750120754340], [-717125643494786169439467980, -129480665182052368664403], [-3090579274643999262634480464, -252345043693819791982260], [-14267496302048140744258990, -115190682863069781624888], [-6068162411590077465641531370, 106966619120243203273260], [5861320515942617645453642920, 171371276283669591872250], [-2262698015252955107693546142, -281498941848838421679840], [-4616208741992882644972413522, -472411804031846289927540], [8016526939829492287062832140, 83653622725745207358531], [-2163181433459198947293483270, 238979416256381504359656], [5515832940829063942410591732, -173144691667707737019075], [-1364017031728940373900830770, -152737127022701574263988], [3168636376696728048297763038, -225660660919554814887780], [-1894835015357570251307638688, -406938913821211700955240], [4133785554934981374354831990, 83137419202432038122844], [-6689639698360437821648724540, 299337538772150744547825], [-3844797911621450991797425220, 242243217846752413877487], [3901281370097669532217422410, 621022499950689042204240], [-4474354679714500676367171570, 669030378628934832632892], [15838702783416765862042455088, 310666556495974829049900], [4995726158914273292446423980, -622009863583508768551029], [-2117140258263682287472734812, -233307222525820500489495], [-11923196549063600569260559390, -309724824724763488220376], [3807604662948122700052827540, 445931549294488118372133], [-1295231439301603184811163090, 355734597011582788822620], [-19832579064466837988997635064, 125156392750963609365330], [-13632144655458709170832146490, 572389194156786378761004], [-14681468137801526272430326800, 471543101154018822011292], [15659396101551031233973907670, 82979397196039861610940], [2913807750938697108394735650, -207324840925082784962520], [10558361806745884901152410460, -557361091037701276528041], [-12920481272822418369010042920, -399795182844029414642970], [-10241768023658776304410522966, -834654419106904059131160], [-6923223173429005660073616564, 487572909170289740428275], [-18328017712280406991060318272, -23828741908275867670800], [5945925633217779665271655490, -537570221601394101593088], [4928219774705016872564639058, -799335862264266998489280], [-1049093631389844550837626068, -383227726236142071490965], [14901030185825757062046174170, 206288962618173448933584], [-4587440461292403734729877090, -713605335913001557767060], [-2029299546223801335061151840, -1928773426288736804017752], [2811966247429839865505443050, 1657942316970540142505040], [-12713701546054314799393608334, 917945561294181213046920], [20687815660784822626360353532, 628057817978439407664735], [-21356374162063546191675695900, -224246972580650677365255], [31770594104000302039692820320, 515524064914126898157528], [11297889556834792077021838950, -374503695579572344047108], [9431748426345437528709310190, -1646176904178614093022660], [-47205096336354177943149948930, -37520107831059729080436], [-34531775015927478237315012800, 485936887157433251044560], [1509154269756907725696604860, -194238036832811223960081], [-24986360035607655383107226444, -1083001276806389627352435], [41513043295770057114678301860, -120178076007471256449783], [-57173705152207738694015342050, -250572444737623125534900], [33280491110598789441357377250, -851091122483257019015520], [3598389141690158336959102826, -1165051505205797257654200], [16589969600981322872959697680, 2198603689619982470484516], [-21218063787693374323187296330, 957920768549236021767804], [-14684675113396737506717399430, -2191681499583699919552176], [25130010990319485139741851846, 1822182437817248402691180], [28693504321307697872237952760, -49312297375862224421970], [17513853661266595706214427230, 1013502099911874043946076], [-44239340524789809378993810852, 1997629580360058059032695], [-41130762177710277670354383130, 608129774836528160318940], [-27090873511913145176905831340, 123295592596727295278037], [-77873184552326211514182057264, -19155194179896369840300], [-38238152457048845636749921290, -683959778558498105083044], [13073271835378311472765719100, 629234799052320367379055], [-17135321558697735841727681590, -728399889162666257674032], [31487963955302198640971291022, 48207677099389700050620], [17994434607035274027791850160, 3247969056096386351917836], [-25979081093719123039820919274, -1413790431353050574813220], [31440513272792139007369672410, 91741355538172977690504], [-59852748932519672190889410912, -1637345803261225291545240], [-13999921399422642200686865388, 3910240534987441212455205], [19739297855035005458361724530, 4538887764032996352876744], [-33807887484345787277634674040, 1920777510264540737081202], [4701339289626222197564965190, 2761650283269462570324108], [-4057908580792176860062825974, -832223651464654562001240], [34128362703077778628683258480, 922661460155240269644348], [20722799656870017351365592036, -2781204639212372551457895], [-93908940289604673096887811620, -512576672745197056719465], [-23705507329848907820935508950, -358322863506746010562872], [-32021097491986727232197302290, 2849855247451875548953980], [-79739815224958947591450374600, -1382993878020451043493762], [53748323738280155378351801690, -882727337885593830260400], [17667135991758967203421338012, -6747410603688133548393945], [-18749739260321237296877696108, 671102838337418735170725], [-61700112731609059504350731760, 3632783226309095108666724], [87995657464448691492859061430, 2310483477304082971307340], [-11742290811899460717723069944, -3089923099806692336767470], [52862463543315812896255051070, -3520347178601381333495220], [52560956102533521027692325228, 3278034435118141206472635], [18700161116298818933126151648, -683513884053110765377800], [39316302753231061943027117090, 3351402440196738840494208], [90266461832015093259192568626, 6721389401113875501189000], [-54999567083478364592324244550, -1949399602008857782738416], [25370740262528795605429115262, -2046997573779075366562740], [14680942341068386020515376330, 4483793744253707975625744], [-73916407882383969343566771800, 3693501059706238598484282], [33205243630273470969983414370, 11109302939254325057594496], [18484728928390269758590116124, -1818861591341813719784985], [-109458214461107479868927904360, -4267432127413912593293802], [95803736074439158193750581648, -8077765863122285052921660], [45523449160856462252486886710, 5327324340790483896124140], [-51855821492897476903813618940, 1565959812661139768564769], [60912538763436445752401212800, 5949885883610312147464416], [-114124782639507879724868441470, 7565538407958438883143840], [16269132912829354871983147590, -5914223547405117095732436], [-11948404505132801171913061644, 8998923558124749533389245], [164066103733531012200420030700, -2279692558512343331381925], [-3506584635105236998234085016, 2022108658321644986092650], [205486922604622075826350539290, -467221824088590608885232], [-140709042145733498146507944608, 7137442108779912257316120], [102681842984338428308910220074, 2408029958157813207242640], [92867832766838646155309605588, -142352376003176559741675], [-41698530686817016172937125514, -7454791901795108185756980], [29462666312043735466708122110, -3951619506948688019365140], [58303367901505327670407423170, -966915354397300681809240], [-30146404321089641652027131600, -5055628958355930133224276], [-23193463993954527613147199910, 6413408448103227784211856], [-142884598262430431317381989210, 2633541381282571008846300], [-181558106074775502784129796840, 7452903141638777939962230], [133105044971242756542325337390, -1081303538668261958552580], [37685635057942367993626007538, -3056350998058363533500280], [67077238017351601968166246540, 7621177302937914447172419], [-78281383436712520766788286340, 14113219912706598640674975], [-238958748797258821968170779630, 1491674056148095242226848], [-116325497153207412495118737450, -1804247351863147548782964], [-122425736997916849491130723740, -15922646920500172721587719], [111410714835446835652385570908, -5049792183955341293194185], [73344382430221573927777363370, 9759662998249139137213128], [243355763499623761802902008174, -4264528056472021774640580], [286022880371280744544634299584, -1091223121786895966798160], [-52689311683087265124935414600, 3048053451176693249241246], [85618326823788931803103805010, 4070845328431267931145480], [-21269783725588525626826671960, 15494699498868061870185018], [-66825360089149105199954444130, -9686367123976204357745700], [-262812844265776696896015714010, -15659443490252882868706356], [171008657624834674569972965520, 122969643420518186350212], [41875728824135652608288109060, 14330911551750534553456545], [-13299695495561710330302901750, 9477664847447944798770768], [417893483374424457304045844430, 5157641912789544233533596], [-21560268232888716545805598740, 11591345894524003418320251], [105587236615277593850394596634, -22307552167349413275779160], [-29073560661987987753420650012, -25260715457413123567058055], [94253939804448808349825175624, -11888846270668251708817950]]
